package com.example.player.view
{
	import com.example.player.events.PlayerEvent;
	
	import flashx.textLayout.formats.VerticalAlign;
	
	import org.osmf.elements.ParallelElement;
	import org.osmf.layout.HorizontalAlign;
	import org.osmf.layout.LayoutMetadata;
	import org.osmf.media.MediaElement;
	import org.osmf.media.MediaResourceBase;
	import org.osmf.media.URLResource;
	import org.osmf.metadata.Metadata;
	import org.robotlegs.mvcs.Mediator;
	
	public class ControlBarPluginSampleMediator extends Mediator
	{
		[Inject]
		public var controlBarView:ControlBarPluginSample;
		
		[Inject]
		public var osmf:OSMFConfiguration;		
		
		private var rootElement:ParallelElement;
		
		public function ControlBarPluginSampleMediator()
		{
			super();
		}
		
		override public function onRegister():void
		{
			this.eventDispatcher.addEventListener(PlayerEvent.PLUGIN_LOADED, onPluginLoaded);
			
			trace("yes we have a view man")
			
			// Construct a parallel media element to hold the main content,
			// and later on, the control bar.
			rootElement = new ParallelElement();
			rootElement.addChild(constructVideoElement());
			
			// Use the layout api to set the parallel element's width and
			// height. Make it as big as the stage currently is:
			var rootElementLayout:LayoutMetadata = new LayoutMetadata();
			rootElement.addMetadata(LayoutMetadata.LAYOUT_NAMESPACE, rootElementLayout);
			rootElementLayout.width = controlBarView.stage.stageWidth;
			rootElementLayout.height = controlBarView.stage.stageHeight;

			// Construct the main element to play back. This will be a
			// parallel element, that will hold the main content to
			// playback, and the control bar (from a plug-in) as its
			// children:
			osmf.mediaElement = rootElement;
			osmf.view = controlBarView;
			
		}
		
		private function onPluginLoaded(event:PlayerEvent):void
		{
			rootElement.addChild(constructControlBarElement());
		}
		
		private function constructVideoElement():MediaElement
		{
			// Construct a metadata object that we can append to the video's collection
			// of metadata. The control bar plug-in will use the metadata to identify
			// the video element as its target:
			var controlBarTarget:Metadata = new Metadata();
			controlBarTarget.addValue(ControlBarPluginSample.ID, "mainContent");
			
			// Construct a video element:
			var video:MediaElement = osmf.factory.createMediaElement(new URLResource(ControlBarPluginSample.VIDEO_URL));
			
			// Add the metadata to the video's metadata:
			video.addMetadata("http://www.osmf.org/samples/controlbar/target", controlBarTarget);
			
			return video;
		}
		
		private function constructControlBarElement():MediaElement
		{
			// Construct a metadata object that we'll send to the media factory on
			// requesting a control bar element to be instantiated. The factory
			// will use it to parameterize the element. Specifically, the ID field
			// will tell the plug-in what the ID of the content it should control
			// is:
			var controlBarSettings:Metadata = new Metadata();
			controlBarSettings.addValue(ControlBarPluginSample.ID, "mainContent");
			
			// Add the metadata to an otherwise empty media resource object:
			var resource:MediaResourceBase = new MediaResourceBase();
			resource.addMetadataValue("http://www.osmf.org/samples/controlbar/settings", controlBarSettings);
			
			// Request the media factory to construct a control bar element. The
			// factory will infer a control bar element is requested by inspecting
			// the resource's metadata (and encountering a metadata object of namespace
			// NS_CONTROL_BAR_SETTINGS there):
			var controlBar:MediaElement = osmf.factory.createMediaElement(resource);
			
			// Set some layout properties on the control bar. Specifically, have it
			// appear at the bottom of the parallel element, horizontally centererd:
			var layout:LayoutMetadata = controlBar.getMetadata(LayoutMetadata.LAYOUT_NAMESPACE) as LayoutMetadata;
			if (layout == null)
			{
				layout = new LayoutMetadata();
				controlBar.addMetadata(LayoutMetadata.LAYOUT_NAMESPACE, layout);
			}
			layout.verticalAlign = VerticalAlign.BOTTOM;
			layout.horizontalAlign = HorizontalAlign.CENTER;
			
			// Make sure that the element shows over the video: element's with a
			// higher order number set are placed higher in the display list:
			layout.index = 1;
			
			return controlBar;
		}
	}
}